Colibri Core
================

.. image:: https://travis-ci.org/proycon/colibri-core.svg?branch=master
    :target: https://travis-ci.org/proycon/colibri-core

*by Maarten van Gompel, proycon@anaproy.nl, Radboud University Nijmegen*

*Licensed under GPLv3 (See http://www.gnu.org/licenses/gpl-3.0.html)*

Colibri core is an NLP tool as well as a C++ and Python library for working
with basic linguistic constructions such as n-grams and skipgrams (i.e patterns
with one or more gaps, either of fixed or dynamic size) in a quick and
memory-efficient way. At the core is the tool ``colibri-patternmodeller`` which
allows you to build, view, manipulate and query pattern models.

Please consult the documentation at http://proycon.github.io/colibri-core 

This software is developed in the scope of the Ph.D. research project
Constructions as Linguistic Bridges. This research examines the identification
and extraction of aligned constructions or patterns across natural languages,
and the usage of such constructions in Machine Translation. The aligned
constructions are not identified on the basis of an extensive and explicitly
defined grammar or expert database of linguistic knowledge, but rather are
implicitly distilled from large amounts of example data. Our notion of
constructions is broad and transcends the idea of words or variable-length
phrases. 

